# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
BRepTools module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_breptools.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _BRepTools
else:
    import _BRepTools

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _BRepTools.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _BRepTools.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BRepTools.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BRepTools.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _BRepTools.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _BRepTools.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _BRepTools.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _BRepTools.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _BRepTools.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _BRepTools.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BRepTools.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _BRepTools.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _BRepTools.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BRepTools.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BRepTools.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BRepTools.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _BRepTools.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _BRepTools:
_BRepTools.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _BRepTools.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.Bnd
import OCC.Core.TColgp
import OCC.Core.BVH
import OCC.Core.Geom
import OCC.Core.GeomAbs
import OCC.Core.Geom2d
import OCC.Core.TopTools
import OCC.Core.BRep
import OCC.Core.Poly
import OCC.Core.TShort

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_BRepTools_History_Create() -> "opencascade::handle< BRepTools_History >":
    return _BRepTools.Handle_BRepTools_History_Create()

def Handle_BRepTools_History_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BRepTools_History >":
    return _BRepTools.Handle_BRepTools_History_DownCast(t)

def Handle_BRepTools_History_IsNull(t: "opencascade::handle< BRepTools_History > const &") -> "bool":
    return _BRepTools.Handle_BRepTools_History_IsNull(t)

def Handle_BRepTools_Modification_Create() -> "opencascade::handle< BRepTools_Modification >":
    return _BRepTools.Handle_BRepTools_Modification_Create()

def Handle_BRepTools_Modification_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BRepTools_Modification >":
    return _BRepTools.Handle_BRepTools_Modification_DownCast(t)

def Handle_BRepTools_Modification_IsNull(t: "opencascade::handle< BRepTools_Modification > const &") -> "bool":
    return _BRepTools.Handle_BRepTools_Modification_IsNull(t)

def Handle_BRepTools_ReShape_Create() -> "opencascade::handle< BRepTools_ReShape >":
    return _BRepTools.Handle_BRepTools_ReShape_Create()

def Handle_BRepTools_ReShape_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BRepTools_ReShape >":
    return _BRepTools.Handle_BRepTools_ReShape_DownCast(t)

def Handle_BRepTools_ReShape_IsNull(t: "opencascade::handle< BRepTools_ReShape > const &") -> "bool":
    return _BRepTools.Handle_BRepTools_ReShape_IsNull(t)

def Handle_BRepTools_GTrsfModification_Create() -> "opencascade::handle< BRepTools_GTrsfModification >":
    return _BRepTools.Handle_BRepTools_GTrsfModification_Create()

def Handle_BRepTools_GTrsfModification_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BRepTools_GTrsfModification >":
    return _BRepTools.Handle_BRepTools_GTrsfModification_DownCast(t)

def Handle_BRepTools_GTrsfModification_IsNull(t: "opencascade::handle< BRepTools_GTrsfModification > const &") -> "bool":
    return _BRepTools.Handle_BRepTools_GTrsfModification_IsNull(t)

def Handle_BRepTools_NurbsConvertModification_Create() -> "opencascade::handle< BRepTools_NurbsConvertModification >":
    return _BRepTools.Handle_BRepTools_NurbsConvertModification_Create()

def Handle_BRepTools_NurbsConvertModification_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BRepTools_NurbsConvertModification >":
    return _BRepTools.Handle_BRepTools_NurbsConvertModification_DownCast(t)

def Handle_BRepTools_NurbsConvertModification_IsNull(t: "opencascade::handle< BRepTools_NurbsConvertModification > const &") -> "bool":
    return _BRepTools.Handle_BRepTools_NurbsConvertModification_IsNull(t)

def Handle_BRepTools_TrsfModification_Create() -> "opencascade::handle< BRepTools_TrsfModification >":
    return _BRepTools.Handle_BRepTools_TrsfModification_Create()

def Handle_BRepTools_TrsfModification_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BRepTools_TrsfModification >":
    return _BRepTools.Handle_BRepTools_TrsfModification_DownCast(t)

def Handle_BRepTools_TrsfModification_IsNull(t: "opencascade::handle< BRepTools_TrsfModification > const &") -> "bool":
    return _BRepTools.Handle_BRepTools_TrsfModification_IsNull(t)
class BRepTools_MapOfVertexPnt2d(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_DataMap< TopoDS_Shape,NCollection_Sequence< gp_Pnt2d >,TopTools_ShapeMapHasher >::iterator":
        return _BRepTools.BRepTools_MapOfVertexPnt2d_begin(self)

    def end(self) -> "NCollection_DataMap< TopoDS_Shape,NCollection_Sequence< gp_Pnt2d >,TopTools_ShapeMapHasher >::iterator":
        return _BRepTools.BRepTools_MapOfVertexPnt2d_end(self)

    def cbegin(self) -> "NCollection_DataMap< TopoDS_Shape,NCollection_Sequence< gp_Pnt2d >,TopTools_ShapeMapHasher >::const_iterator":
        return _BRepTools.BRepTools_MapOfVertexPnt2d_cbegin(self)

    def cend(self) -> "NCollection_DataMap< TopoDS_Shape,NCollection_Sequence< gp_Pnt2d >,TopTools_ShapeMapHasher >::const_iterator":
        return _BRepTools.BRepTools_MapOfVertexPnt2d_cend(self)

    def __init__(self, *args):
        _BRepTools.BRepTools_MapOfVertexPnt2d_swiginit(self, _BRepTools.new_BRepTools_MapOfVertexPnt2d(*args))

    def Exchange(self, theOther: "BRepTools_MapOfVertexPnt2d") -> "void":
        return _BRepTools.BRepTools_MapOfVertexPnt2d_Exchange(self, theOther)

    def Assign(self, theOther: "BRepTools_MapOfVertexPnt2d") -> "NCollection_DataMap< TopoDS_Shape,TColgp_SequenceOfPnt2d,TopTools_ShapeMapHasher > &":
        return _BRepTools.BRepTools_MapOfVertexPnt2d_Assign(self, theOther)

    def Set(self, theOther: "BRepTools_MapOfVertexPnt2d") -> "NCollection_DataMap< TopoDS_Shape,TColgp_SequenceOfPnt2d,TopTools_ShapeMapHasher > &":
        return _BRepTools.BRepTools_MapOfVertexPnt2d_Set(self, theOther)

    def ReSize(self, N: "Standard_Integer const") -> "void":
        return _BRepTools.BRepTools_MapOfVertexPnt2d_ReSize(self, N)

    def Bind(self, theKey: "TopoDS_Shape", theItem: "TColgp_SequenceOfPnt2d") -> "Standard_Boolean":
        return _BRepTools.BRepTools_MapOfVertexPnt2d_Bind(self, theKey, theItem)

    def Bound(self, theKey: "TopoDS_Shape", theItem: "TColgp_SequenceOfPnt2d") -> "NCollection_Sequence< gp_Pnt2d > *":
        return _BRepTools.BRepTools_MapOfVertexPnt2d_Bound(self, theKey, theItem)

    def IsBound(self, theKey: "TopoDS_Shape") -> "Standard_Boolean":
        return _BRepTools.BRepTools_MapOfVertexPnt2d_IsBound(self, theKey)

    def UnBind(self, theKey: "TopoDS_Shape") -> "Standard_Boolean":
        return _BRepTools.BRepTools_MapOfVertexPnt2d_UnBind(self, theKey)

    def Seek(self, theKey: "TopoDS_Shape") -> "NCollection_Sequence< gp_Pnt2d > const *":
        return _BRepTools.BRepTools_MapOfVertexPnt2d_Seek(self, theKey)

    def Find(self, *args) -> "Standard_Boolean":
        return _BRepTools.BRepTools_MapOfVertexPnt2d_Find(self, *args)

    def ChangeSeek(self, theKey: "TopoDS_Shape") -> "NCollection_Sequence< gp_Pnt2d > *":
        return _BRepTools.BRepTools_MapOfVertexPnt2d_ChangeSeek(self, theKey)

    def ChangeFind(self, theKey: "TopoDS_Shape") -> "NCollection_Sequence< gp_Pnt2d > &":
        return _BRepTools.BRepTools_MapOfVertexPnt2d_ChangeFind(self, theKey)

    def __call__(self, *args) -> "NCollection_Sequence< gp_Pnt2d > &":
        return _BRepTools.BRepTools_MapOfVertexPnt2d___call__(self, *args)

    def Clear(self, *args) -> "void":
        return _BRepTools.BRepTools_MapOfVertexPnt2d_Clear(self, *args)
    __swig_destroy__ = _BRepTools.delete_BRepTools_MapOfVertexPnt2d

    def Size(self) -> "Standard_Integer":
        return _BRepTools.BRepTools_MapOfVertexPnt2d_Size(self)

# Register BRepTools_MapOfVertexPnt2d in _BRepTools:
_BRepTools.BRepTools_MapOfVertexPnt2d_swigregister(BRepTools_MapOfVertexPnt2d)

class breptools(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def AddUVBounds(*args) -> "void":
        r"""
        Adds to the box <b> the bounding values in the parametric space of f.

        Parameters
        ----------
        F: TopoDS_Face
        B: Bnd_Box2d

        Returns
        -------
        None
        Adds to the box <b> the bounding values of the wire in the parametric space of f.

        Parameters
        ----------
        F: TopoDS_Face
        W: TopoDS_Wire
        B: Bnd_Box2d

        Returns
        -------
        None
        Adds to the box <b> the bounding values of the edge in the parametric space of f.

        Parameters
        ----------
        F: TopoDS_Face
        E: TopoDS_Edge
        B: Bnd_Box2d

        Returns
        -------
        None

        """
        return _BRepTools.breptools_AddUVBounds(*args)

    @staticmethod
    def Clean(*args) -> "void":
        r"""
        Removes all cashed polygonal representation of the shape, i.e. the triangulations of the faces of <s> and polygons on triangulations and polygons 3d of the edges. in case polygonal representation is the only available representation for the shape (shape does not have geometry) it is not removed.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepTools.breptools_Clean(*args)

    @staticmethod
    def CleanGeometry(*args) -> "void":
        r"""
        Removes geometry (curves and surfaces) from all edges and faces of the shape.

        Parameters
        ----------
        theShape: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepTools.breptools_CleanGeometry(*args)

    @staticmethod
    def Compare(*args) -> "Standard_Boolean":
        r"""
        Returns true if the distance between the two vertices is lower than their tolerance.

        Parameters
        ----------
        V1: TopoDS_Vertex
        V2: TopoDS_Vertex

        Returns
        -------
        bool
        Returns true if the distance between the two edges is lower than their tolerance.

        Parameters
        ----------
        E1: TopoDS_Edge
        E2: TopoDS_Edge

        Returns
        -------
        bool

        """
        return _BRepTools.breptools_Compare(*args)

    @staticmethod
    def DetectClosedness(*args) -> "Standard_Boolean &, Standard_Boolean &":
        r"""
        Detect closedness of face in u and v directions.

        Parameters
        ----------
        theFace: TopoDS_Face

        Returns
        -------
        theUclosed: bool
        theVclosed: bool

        """
        return _BRepTools.breptools_DetectClosedness(*args)

    @staticmethod
    def EvalAndUpdateTol(*args) -> "Standard_Real":
        r"""
        Evals real tolerance of edge <thee>. <thec3d>, <thec2d>, <thes>, <thef>, <thel> are correspondently 3d curve of edge, 2d curve on surface <thes> and rang of edge if calculated tolerance is more then current edge tolerance, edge is updated. method returns actual tolerance of edge.

        Parameters
        ----------
        theE: TopoDS_Edge
        theC3d: Geom_Curve
        theC2d: Geom2d_Curve
        theS: Geom_Surface
        theF: float
        theL: float

        Returns
        -------
        float

        """
        return _BRepTools.breptools_EvalAndUpdateTol(*args)

    @staticmethod
    def IsReallyClosed(*args) -> "Standard_Boolean":
        r"""
        Verifies that the edge <e> is found two times on the face <f> before calling brep_tool::isclosed.

        Parameters
        ----------
        E: TopoDS_Edge
        F: TopoDS_Face

        Returns
        -------
        bool

        """
        return _BRepTools.breptools_IsReallyClosed(*args)

    @staticmethod
    def Map3DEdges(*args) -> "void":
        r"""
        Stores in the map <m> all the 3d topology edges of <s>.

        Parameters
        ----------
        S: TopoDS_Shape
        M: TopTools_IndexedMapOfShape

        Returns
        -------
        None

        """
        return _BRepTools.breptools_Map3DEdges(*args)

    @staticmethod
    def OriEdgeInFace(*args) -> "TopAbs_Orientation":
        r"""
        Returns the cumul of the orientation of <edge> and thc containing wire in <face>.

        Parameters
        ----------
        theEdge: TopoDS_Edge
        theFace: TopoDS_Face

        Returns
        -------
        TopAbs_Orientation

        """
        return _BRepTools.breptools_OriEdgeInFace(*args)

    @staticmethod
    def OuterWire(*args) -> "TopoDS_Wire":
        r"""
        Returns the outer most wire of <f>. returns a null wire if <f> has no wires.

        Parameters
        ----------
        F: TopoDS_Face

        Returns
        -------
        TopoDS_Wire

        """
        return _BRepTools.breptools_OuterWire(*args)

    @staticmethod
    def Read(*args) -> "Standard_Boolean":
        r"""
        Reads a shape from <file>, returns it in <sh>. <b> is used to build the shape.

        Parameters
        ----------
        Sh: TopoDS_Shape
        File: char *
        B: BRep_Builder
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        bool

        """
        return _BRepTools.breptools_Read(*args)

    @staticmethod
    def RemoveInternals(*args) -> "void":
        r"""
        Removes internal sub-shapes from the shape. the check on internal status is based on orientation of sub-shapes, classification is not performed. before removal of internal sub-shapes the algorithm checks if such removal is not going to break topological connectivity between sub-shapes. the flag <theforce> if set to true disables the connectivity check and clears the given shape from all sub-shapes with internal orientation.

        Parameters
        ----------
        theS: TopoDS_Shape
        theForce: bool,optional
        	default value is Standard_False

        Returns
        -------
        None

        """
        return _BRepTools.breptools_RemoveInternals(*args)

    @staticmethod
    def RemoveUnusedPCurves(*args) -> "void":
        r"""
        Removes all the pcurves of the edges of <s> that refer to surfaces not belonging to any face of <s>.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepTools.breptools_RemoveUnusedPCurves(*args)

    @staticmethod
    def Triangulation(*args) -> "Standard_Boolean":
        r"""
        Verifies that each face from the shape has got a triangulation with a deflection smaller or equal to specified one and the edges a discretization on this triangulation. @param theshape [in] shape to verify @param thelindefl [in] maximum allowed linear deflection @param thetocheckfreeedges [in] if true, then free edges are required to have 3d polygon returns false if input shape contains faces without triangulation, or that triangulation has worse (greater) deflection than specified one, or edges in shape lack polygons on triangulation or free edges in shape lack 3d polygons.

        Parameters
        ----------
        theShape: TopoDS_Shape
        theLinDefl: float
        theToCheckFreeEdges: bool,optional
        	default value is Standard_False

        Returns
        -------
        bool

        """
        return _BRepTools.breptools_Triangulation(*args)

    @staticmethod
    def UVBounds(*args) -> "Standard_Real &, Standard_Real &, Standard_Real &, Standard_Real &":
        r"""
        Returns in umin, umax, vmin, vmax the bounding values in the parametric space of f.

        Parameters
        ----------
        F: TopoDS_Face

        Returns
        -------
        UMin: float
        UMax: float
        VMin: float
        VMax: float
        Returns in umin, umax, vmin, vmax the bounding values of the wire in the parametric space of f.

        Parameters
        ----------
        F: TopoDS_Face
        W: TopoDS_Wire

        Returns
        -------
        UMin: float
        UMax: float
        VMin: float
        VMax: float
        Returns in umin, umax, vmin, vmax the bounding values of the edge in the parametric space of f.

        Parameters
        ----------
        F: TopoDS_Face
        E: TopoDS_Edge

        Returns
        -------
        UMin: float
        UMax: float
        VMin: float
        VMax: float

        """
        return _BRepTools.breptools_UVBounds(*args)

    @staticmethod
    def Update(*args) -> "void":
        r"""
        Update a vertex (nothing is done).

        Parameters
        ----------
        V: TopoDS_Vertex

        Returns
        -------
        None
        Update an edge, compute 2d bounding boxes.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        None
        Update a wire (nothing is done).

        Parameters
        ----------
        W: TopoDS_Wire

        Returns
        -------
        None
        Update a face, update uv points.

        Parameters
        ----------
        F: TopoDS_Face

        Returns
        -------
        None
        Update a shell (nothing is done).

        Parameters
        ----------
        S: TopoDS_Shell

        Returns
        -------
        None
        Update a solid (nothing is done).

        Parameters
        ----------
        S: TopoDS_Solid

        Returns
        -------
        None
        Update a composite solid (nothing is done).

        Parameters
        ----------
        C: TopoDS_CompSolid

        Returns
        -------
        None
        Update a compound (nothing is done).

        Parameters
        ----------
        C: TopoDS_Compound

        Returns
        -------
        None
        Update a shape, call the corect update.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepTools.breptools_Update(*args)

    @staticmethod
    def UpdateFaceUVPoints(*args) -> "void":
        r"""
        For each edge of the face <f> reset the uv points to the bounding points of the parametric curve of the edge on the face.

        Parameters
        ----------
        theF: TopoDS_Face

        Returns
        -------
        None

        """
        return _BRepTools.breptools_UpdateFaceUVPoints(*args)

    @staticmethod
    def Write(*args) -> "Standard_Boolean":
        r"""
        Writes <sh> in <file>.

        Parameters
        ----------
        Sh: TopoDS_Shape
        File: char *
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        bool

        """
        return _BRepTools.breptools_Write(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _BRepTools.breptools_swiginit(self, _BRepTools.new_breptools())
    __swig_destroy__ = _BRepTools.delete_breptools

# Register breptools in _BRepTools:
_BRepTools.breptools_swigregister(breptools)

def breptools_AddUVBounds(*args) -> "void":
    r"""
    Adds to the box <b> the bounding values in the parametric space of f.

    Parameters
    ----------
    F: TopoDS_Face
    B: Bnd_Box2d

    Returns
    -------
    None
    Adds to the box <b> the bounding values of the wire in the parametric space of f.

    Parameters
    ----------
    F: TopoDS_Face
    W: TopoDS_Wire
    B: Bnd_Box2d

    Returns
    -------
    None
    Adds to the box <b> the bounding values of the edge in the parametric space of f.

    Parameters
    ----------
    F: TopoDS_Face
    E: TopoDS_Edge
    B: Bnd_Box2d

    Returns
    -------
    None

    """
    return _BRepTools.breptools_AddUVBounds(*args)

def breptools_Clean(*args) -> "void":
    r"""
    Removes all cashed polygonal representation of the shape, i.e. the triangulations of the faces of <s> and polygons on triangulations and polygons 3d of the edges. in case polygonal representation is the only available representation for the shape (shape does not have geometry) it is not removed.

    Parameters
    ----------
    S: TopoDS_Shape

    Returns
    -------
    None

    """
    return _BRepTools.breptools_Clean(*args)

def breptools_CleanGeometry(*args) -> "void":
    r"""
    Removes geometry (curves and surfaces) from all edges and faces of the shape.

    Parameters
    ----------
    theShape: TopoDS_Shape

    Returns
    -------
    None

    """
    return _BRepTools.breptools_CleanGeometry(*args)

def breptools_Compare(*args) -> "Standard_Boolean":
    r"""
    Returns true if the distance between the two vertices is lower than their tolerance.

    Parameters
    ----------
    V1: TopoDS_Vertex
    V2: TopoDS_Vertex

    Returns
    -------
    bool
    Returns true if the distance between the two edges is lower than their tolerance.

    Parameters
    ----------
    E1: TopoDS_Edge
    E2: TopoDS_Edge

    Returns
    -------
    bool

    """
    return _BRepTools.breptools_Compare(*args)

def breptools_DetectClosedness(*args) -> "Standard_Boolean &, Standard_Boolean &":
    r"""
    Detect closedness of face in u and v directions.

    Parameters
    ----------
    theFace: TopoDS_Face

    Returns
    -------
    theUclosed: bool
    theVclosed: bool

    """
    return _BRepTools.breptools_DetectClosedness(*args)

def breptools_EvalAndUpdateTol(*args) -> "Standard_Real":
    r"""
    Evals real tolerance of edge <thee>. <thec3d>, <thec2d>, <thes>, <thef>, <thel> are correspondently 3d curve of edge, 2d curve on surface <thes> and rang of edge if calculated tolerance is more then current edge tolerance, edge is updated. method returns actual tolerance of edge.

    Parameters
    ----------
    theE: TopoDS_Edge
    theC3d: Geom_Curve
    theC2d: Geom2d_Curve
    theS: Geom_Surface
    theF: float
    theL: float

    Returns
    -------
    float

    """
    return _BRepTools.breptools_EvalAndUpdateTol(*args)

def breptools_IsReallyClosed(*args) -> "Standard_Boolean":
    r"""
    Verifies that the edge <e> is found two times on the face <f> before calling brep_tool::isclosed.

    Parameters
    ----------
    E: TopoDS_Edge
    F: TopoDS_Face

    Returns
    -------
    bool

    """
    return _BRepTools.breptools_IsReallyClosed(*args)

def breptools_Map3DEdges(*args) -> "void":
    r"""
    Stores in the map <m> all the 3d topology edges of <s>.

    Parameters
    ----------
    S: TopoDS_Shape
    M: TopTools_IndexedMapOfShape

    Returns
    -------
    None

    """
    return _BRepTools.breptools_Map3DEdges(*args)

def breptools_OriEdgeInFace(*args) -> "TopAbs_Orientation":
    r"""
    Returns the cumul of the orientation of <edge> and thc containing wire in <face>.

    Parameters
    ----------
    theEdge: TopoDS_Edge
    theFace: TopoDS_Face

    Returns
    -------
    TopAbs_Orientation

    """
    return _BRepTools.breptools_OriEdgeInFace(*args)

def breptools_OuterWire(*args) -> "TopoDS_Wire":
    r"""
    Returns the outer most wire of <f>. returns a null wire if <f> has no wires.

    Parameters
    ----------
    F: TopoDS_Face

    Returns
    -------
    TopoDS_Wire

    """
    return _BRepTools.breptools_OuterWire(*args)

def breptools_Read(*args) -> "Standard_Boolean":
    r"""
    Reads a shape from <file>, returns it in <sh>. <b> is used to build the shape.

    Parameters
    ----------
    Sh: TopoDS_Shape
    File: char *
    B: BRep_Builder
    theProgress: Message_ProgressRange,optional
    	default value is Message_ProgressRange()

    Returns
    -------
    bool

    """
    return _BRepTools.breptools_Read(*args)

def breptools_RemoveInternals(*args) -> "void":
    r"""
    Removes internal sub-shapes from the shape. the check on internal status is based on orientation of sub-shapes, classification is not performed. before removal of internal sub-shapes the algorithm checks if such removal is not going to break topological connectivity between sub-shapes. the flag <theforce> if set to true disables the connectivity check and clears the given shape from all sub-shapes with internal orientation.

    Parameters
    ----------
    theS: TopoDS_Shape
    theForce: bool,optional
    	default value is Standard_False

    Returns
    -------
    None

    """
    return _BRepTools.breptools_RemoveInternals(*args)

def breptools_RemoveUnusedPCurves(*args) -> "void":
    r"""
    Removes all the pcurves of the edges of <s> that refer to surfaces not belonging to any face of <s>.

    Parameters
    ----------
    S: TopoDS_Shape

    Returns
    -------
    None

    """
    return _BRepTools.breptools_RemoveUnusedPCurves(*args)

def breptools_Triangulation(*args) -> "Standard_Boolean":
    r"""
    Verifies that each face from the shape has got a triangulation with a deflection smaller or equal to specified one and the edges a discretization on this triangulation. @param theshape [in] shape to verify @param thelindefl [in] maximum allowed linear deflection @param thetocheckfreeedges [in] if true, then free edges are required to have 3d polygon returns false if input shape contains faces without triangulation, or that triangulation has worse (greater) deflection than specified one, or edges in shape lack polygons on triangulation or free edges in shape lack 3d polygons.

    Parameters
    ----------
    theShape: TopoDS_Shape
    theLinDefl: float
    theToCheckFreeEdges: bool,optional
    	default value is Standard_False

    Returns
    -------
    bool

    """
    return _BRepTools.breptools_Triangulation(*args)

def breptools_UVBounds(*args) -> "Standard_Real &, Standard_Real &, Standard_Real &, Standard_Real &":
    r"""
    Returns in umin, umax, vmin, vmax the bounding values in the parametric space of f.

    Parameters
    ----------
    F: TopoDS_Face

    Returns
    -------
    UMin: float
    UMax: float
    VMin: float
    VMax: float
    Returns in umin, umax, vmin, vmax the bounding values of the wire in the parametric space of f.

    Parameters
    ----------
    F: TopoDS_Face
    W: TopoDS_Wire

    Returns
    -------
    UMin: float
    UMax: float
    VMin: float
    VMax: float
    Returns in umin, umax, vmin, vmax the bounding values of the edge in the parametric space of f.

    Parameters
    ----------
    F: TopoDS_Face
    E: TopoDS_Edge

    Returns
    -------
    UMin: float
    UMax: float
    VMin: float
    VMax: float

    """
    return _BRepTools.breptools_UVBounds(*args)

def breptools_Update(*args) -> "void":
    r"""
    Update a vertex (nothing is done).

    Parameters
    ----------
    V: TopoDS_Vertex

    Returns
    -------
    None
    Update an edge, compute 2d bounding boxes.

    Parameters
    ----------
    E: TopoDS_Edge

    Returns
    -------
    None
    Update a wire (nothing is done).

    Parameters
    ----------
    W: TopoDS_Wire

    Returns
    -------
    None
    Update a face, update uv points.

    Parameters
    ----------
    F: TopoDS_Face

    Returns
    -------
    None
    Update a shell (nothing is done).

    Parameters
    ----------
    S: TopoDS_Shell

    Returns
    -------
    None
    Update a solid (nothing is done).

    Parameters
    ----------
    S: TopoDS_Solid

    Returns
    -------
    None
    Update a composite solid (nothing is done).

    Parameters
    ----------
    C: TopoDS_CompSolid

    Returns
    -------
    None
    Update a compound (nothing is done).

    Parameters
    ----------
    C: TopoDS_Compound

    Returns
    -------
    None
    Update a shape, call the corect update.

    Parameters
    ----------
    S: TopoDS_Shape

    Returns
    -------
    None

    """
    return _BRepTools.breptools_Update(*args)

def breptools_UpdateFaceUVPoints(*args) -> "void":
    r"""
    For each edge of the face <f> reset the uv points to the bounding points of the parametric curve of the edge on the face.

    Parameters
    ----------
    theF: TopoDS_Face

    Returns
    -------
    None

    """
    return _BRepTools.breptools_UpdateFaceUVPoints(*args)

def breptools_Write(*args) -> "Standard_Boolean":
    r"""
    Writes <sh> in <file>.

    Parameters
    ----------
    Sh: TopoDS_Shape
    File: char *
    theProgress: Message_ProgressRange,optional
    	default value is Message_ProgressRange()

    Returns
    -------
    bool

    """
    return _BRepTools.breptools_Write(*args)

class BRepTools_History(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    TRelationType_Removed = _BRepTools.BRepTools_History_TRelationType_Removed
    TRelationType_Generated = _BRepTools.BRepTools_History_TRelationType_Generated
    TRelationType_Modified = _BRepTools.BRepTools_History_TRelationType_Modified


    class TRelationType(IntEnum):
    	TRelationType_Removed = 0
    	TRelationType_Generated = 1
    	TRelationType_Modified = 2
    TRelationType_Removed = TRelationType.TRelationType_Removed
    TRelationType_Generated = TRelationType.TRelationType_Generated
    TRelationType_Modified = TRelationType.TRelationType_Modified


    def AddGenerated(self, *args) -> "void":
        r"""
        Set the second shape as generated one from the first shape.

        Parameters
        ----------
        theInitial: TopoDS_Shape
        theGenerated: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepTools.BRepTools_History_AddGenerated(self, *args)

    def AddModified(self, *args) -> "void":
        r"""
        Set the second shape as modified one from the first shape.

        Parameters
        ----------
        theInitial: TopoDS_Shape
        theModified: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepTools.BRepTools_History_AddModified(self, *args)

    def Clear(self, *args) -> "void":
        r"""
        Clears the history.

        Returns
        -------
        None

        """
        return _BRepTools.BRepTools_History_Clear(self, *args)

    def DumpToString(self) -> "std::string":
        r"""DumpToString(BRepTools_History self) -> std::string"""
        return _BRepTools.BRepTools_History_DumpToString(self)

    def Generated(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        No available documentation.

        Parameters
        ----------
        theInitial: TopoDS_Shape

        Returns
        -------
        TopTools_ListOfShape

        """
        return _BRepTools.BRepTools_History_Generated(self, *args)

    def HasGenerated(self, *args) -> "Standard_Boolean":
        r"""
        Returns 'true' if there any shapes with generated elements present.

        Returns
        -------
        bool

        """
        return _BRepTools.BRepTools_History_HasGenerated(self, *args)

    def HasModified(self, *args) -> "Standard_Boolean":
        r"""
        Returns 'true' if there any modified shapes present.

        Returns
        -------
        bool

        """
        return _BRepTools.BRepTools_History_HasModified(self, *args)

    def HasRemoved(self, *args) -> "Standard_Boolean":
        r"""
        Returns 'true' if there any removed shapes present.

        Returns
        -------
        bool

        """
        return _BRepTools.BRepTools_History_HasRemoved(self, *args)

    def IsRemoved(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        theInitial: TopoDS_Shape

        Returns
        -------
        bool

        """
        return _BRepTools.BRepTools_History_IsRemoved(self, *args)

    @staticmethod
    def IsSupportedType(*args) -> "Standard_Boolean":
        r"""
        Returns 'true' if the type of the shape is supported by the history.

        Parameters
        ----------
        theShape: TopoDS_Shape

        Returns
        -------
        bool

        """
        return _BRepTools.BRepTools_History_IsSupportedType(*args)

    def Modified(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        No available documentation.

        Parameters
        ----------
        theInitial: TopoDS_Shape

        Returns
        -------
        TopTools_ListOfShape

        """
        return _BRepTools.BRepTools_History_Modified(self, *args)

    def Remove(self, *args) -> "void":
        r"""
        Set the shape as removed one.

        Parameters
        ----------
        theRemoved: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepTools.BRepTools_History_Remove(self, *args)

    def ReplaceGenerated(self, *args) -> "void":
        r"""
        Set the second shape as the only generated one from the first one.

        Parameters
        ----------
        theInitial: TopoDS_Shape
        theGenerated: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepTools.BRepTools_History_ReplaceGenerated(self, *args)

    def ReplaceModified(self, *args) -> "void":
        r"""
        Set the second shape as the only modified one from the first one.

        Parameters
        ----------
        theInitial: TopoDS_Shape
        theModified: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepTools.BRepTools_History_ReplaceModified(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BRepTools_History_DownCast(t)


    __repr__ = _dumps_object

    @methodnotwrapped
    def BRepTools_History(self):
    	pass

    @methodnotwrapped
    def Merge(self):
    	pass


    def __init__(self):
        r"""__init__(BRepTools_History self) -> BRepTools_History"""
        _BRepTools.BRepTools_History_swiginit(self, _BRepTools.new_BRepTools_History())
    __swig_destroy__ = _BRepTools.delete_BRepTools_History

# Register BRepTools_History in _BRepTools:
_BRepTools.BRepTools_History_swigregister(BRepTools_History)

def BRepTools_History_IsSupportedType(*args) -> "Standard_Boolean":
    r"""
    Returns 'true' if the type of the shape is supported by the history.

    Parameters
    ----------
    theShape: TopoDS_Shape

    Returns
    -------
    bool

    """
    return _BRepTools.BRepTools_History_IsSupportedType(*args)

class BRepTools_Modification(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def Continuity(self, *args) -> "GeomAbs_Shape":
        r"""
        Returns the continuity of <newe> between <newf1> and <newf2>. <newe> is the new edge created from <e>. <newf1> (resp. <newf2>) is the new face created from <f1> (resp. <f2>).

        Parameters
        ----------
        E: TopoDS_Edge
        F1: TopoDS_Face
        F2: TopoDS_Face
        NewE: TopoDS_Edge
        NewF1: TopoDS_Face
        NewF2: TopoDS_Face

        Returns
        -------
        GeomAbs_Shape

        """
        return _BRepTools.BRepTools_Modification_Continuity(self, *args)

    def NewCurve(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the edge, e, has been modified. if the edge has been modified: - c is the new geometry associated with the edge, - l is its new location, and - tol is the new tolerance. if the edge has not been modified, this function returns false, and the values of c, l and tol are not significant.

        Parameters
        ----------
        E: TopoDS_Edge
        C: Geom_Curve
        L: TopLoc_Location

        Returns
        -------
        Tol: float

        """
        return _BRepTools.BRepTools_Modification_NewCurve(self, *args)

    def NewCurve2d(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the edge, e, has a new curve on surface on the face, f. if a new curve exists: - c is the new geometry of the edge, - l is the new location, and - tol is the new tolerance. newe is the new edge created from e, and newf is the new face created from f. if there is no new curve on the face, this function returns false, and the values of c, l and tol are not significant.

        Parameters
        ----------
        E: TopoDS_Edge
        F: TopoDS_Face
        NewE: TopoDS_Edge
        NewF: TopoDS_Face
        C: Geom2d_Curve

        Returns
        -------
        Tol: float

        """
        return _BRepTools.BRepTools_Modification_NewCurve2d(self, *args)

    def NewParameter(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the vertex v has a new parameter on the edge e. if a new parameter exists: - p is the parameter, and - tol is the new tolerance. if there is no new parameter this function returns false, and the values of p and tol are not significant.

        Parameters
        ----------
        V: TopoDS_Vertex
        E: TopoDS_Edge

        Returns
        -------
        P: float
        Tol: float

        """
        return _BRepTools.BRepTools_Modification_NewParameter(self, *args)

    def NewPoint(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the vertex v has been modified. if v has been modified: - p is the new geometry of the vertex, and - tol is the new tolerance. if the vertex has not been modified this function returns false, and the values of p and tol are not significant.

        Parameters
        ----------
        V: TopoDS_Vertex
        P: gp_Pnt

        Returns
        -------
        Tol: float

        """
        return _BRepTools.BRepTools_Modification_NewPoint(self, *args)

    def NewPolygon(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the edge has been modified according to changed polygon. if the edge has been modified: - p is a new polygon.

        Parameters
        ----------
        E: TopoDS_Edge
        P: Poly_Polygon3D

        Returns
        -------
        bool

        """
        return _BRepTools.BRepTools_Modification_NewPolygon(self, *args)

    def NewPolygonOnTriangulation(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the edge has been modified according to changed polygon on triangulation. if the edge has been modified: - p is a new polygon on triangulation.

        Parameters
        ----------
        E: TopoDS_Edge
        F: TopoDS_Face
        P: Poly_PolygonOnTriangulation

        Returns
        -------
        bool

        """
        return _BRepTools.BRepTools_Modification_NewPolygonOnTriangulation(self, *args)

    def NewSurface(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the face, f, has been modified. if the face has been modified: - s is the new geometry of the face, - l is its new location, and - tol is the new tolerance. the flag, revwires, is set to true when the modification reverses the normal of the surface, (i.e. the wires have to be reversed). the flag, revface, is set to true if the orientation of the modified face changes in the shells which contain it. if the face has not been modified this function returns false, and the values of s, l, tol, revwires and revface are not significant.

        Parameters
        ----------
        F: TopoDS_Face
        S: Geom_Surface
        L: TopLoc_Location

        Returns
        -------
        Tol: float
        RevWires: bool
        RevFace: bool

        """
        return _BRepTools.BRepTools_Modification_NewSurface(self, *args)

    def NewTriangulation(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the face has been modified according to changed triangulation. if the face has been modified: - t is a new triangulation on the face.

        Parameters
        ----------
        F: TopoDS_Face
        T: Poly_Triangulation

        Returns
        -------
        bool

        """
        return _BRepTools.BRepTools_Modification_NewTriangulation(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BRepTools_Modification_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BRepTools.delete_BRepTools_Modification

# Register BRepTools_Modification in _BRepTools:
_BRepTools.BRepTools_Modification_swigregister(BRepTools_Modification)

class BRepTools_Modifier(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates an empty modifier.

        Parameters
        ----------
        theMutableInput: bool,optional
        	default value is Standard_False

        Returns
        -------
        None
        Creates a modifier on the shape <s>.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        None
        Creates a modifier on the shape <s>, and performs the modifications described by <m>.

        Parameters
        ----------
        S: TopoDS_Shape
        M: BRepTools_Modification

        Returns
        -------
        None

        """
        _BRepTools.BRepTools_Modifier_swiginit(self, _BRepTools.new_BRepTools_Modifier(*args))

    def Init(self, *args) -> "void":
        r"""
        Initializes the modifier with the shape <s>.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepTools.BRepTools_Modifier_Init(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns standard_true if the modification has been computed successfully.

        Returns
        -------
        bool

        """
        return _BRepTools.BRepTools_Modifier_IsDone(self, *args)

    def IsMutableInput(self, *args) -> "Standard_Boolean":
        r"""
        Returns the current mutable input state.

        Returns
        -------
        bool

        """
        return _BRepTools.BRepTools_Modifier_IsMutableInput(self, *args)

    def ModifiedShape(self, *args) -> "TopoDS_Shape const":
        r"""
        Returns the modified shape corresponding to <s>.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepTools.BRepTools_Modifier_ModifiedShape(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        Performs the modifications described by <m>.

        Parameters
        ----------
        M: BRepTools_Modification
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        None

        """
        return _BRepTools.BRepTools_Modifier_Perform(self, *args)

    def SetMutableInput(self, *args) -> "void":
        r"""
        Sets the mutable input state if true then the input (original) shape can be modified during modification process.

        Parameters
        ----------
        theMutableInput: bool

        Returns
        -------
        None

        """
        return _BRepTools.BRepTools_Modifier_SetMutableInput(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepTools.delete_BRepTools_Modifier

# Register BRepTools_Modifier in _BRepTools:
_BRepTools.BRepTools_Modifier_swigregister(BRepTools_Modifier)

class BRepTools_Quilt(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _BRepTools.BRepTools_Quilt_swiginit(self, _BRepTools.new_BRepTools_Quilt(*args))

    def Add(self, *args) -> "void":
        r"""
        Add the faces of <s> to the quilt, the faces containing bounded edges are copied.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepTools.BRepTools_Quilt_Add(self, *args)

    def Bind(self, *args) -> "void":
        r"""
        Binds <enew> to be the new edge instead of <eold>. //! the faces of the added shape containing <eold> will be copied to substitute <eold> by <enew>. //! the vertices of <eold> will be bound to the vertices of <enew> with the same orientation. //! if <eold> and <enew> have different orientations the curves are considered to be opposite and the pcurves of <eold> will be copied and reversed in the new faces. //! <eold> must belong to the next added shape, <enew> must belong to a shape added before.

        Parameters
        ----------
        Eold: TopoDS_Edge
        Enew: TopoDS_Edge

        Returns
        -------
        None
        Binds <vnew> to be a new vertex instead of <vold>. //! the faces of the added shape containing <vold> will be copied to substitute <vold> by <vnew>.

        Parameters
        ----------
        Vold: TopoDS_Vertex
        Vnew: TopoDS_Vertex

        Returns
        -------
        None

        """
        return _BRepTools.BRepTools_Quilt_Bind(self, *args)

    def Copy(self, *args) -> "TopoDS_Shape const":
        r"""
        Returns the shape substitued to <s> in the quilt.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepTools.BRepTools_Quilt_Copy(self, *args)

    def IsCopied(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if <s> has been copied (<s> is a vertex, an edge or a face).

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        bool

        """
        return _BRepTools.BRepTools_Quilt_IsCopied(self, *args)

    def Shells(self, *args) -> "TopoDS_Shape":
        r"""
        Returns a compound of shells made from the current set of faces. the shells will be flagged as closed or not closed.

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepTools.BRepTools_Quilt_Shells(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepTools.delete_BRepTools_Quilt

# Register BRepTools_Quilt in _BRepTools:
_BRepTools.BRepTools_Quilt_swigregister(BRepTools_Quilt)

class BRepTools_ReShape(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns an empty reshape.

        Returns
        -------
        None

        """
        _BRepTools.BRepTools_ReShape_swiginit(self, _BRepTools.new_BRepTools_ReShape(*args))

    def Apply(self, *args) -> "TopoDS_Shape":
        r"""
        Applies the substitutions requests to a shape. //! <until> gives the level of type until which requests are taken into account. for subshapes of the type <until> no rebuild and futher exploring are done. //! note: each subshape can be replaced by shape of the same type or by shape containing only shapes of that type (for example, topods_edge can be replaced by topods_edge, topods_wire or topods_compound containing topods_edges). if incompatible shape type is encountered, it is ignored and flag fail1 is set in status.

        Parameters
        ----------
        shape: TopoDS_Shape
        until: TopAbs_ShapeEnum,optional
        	default value is TopAbs_SHAPE

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepTools.BRepTools_ReShape_Apply(self, *args)

    def Clear(self, *args) -> "void":
        r"""
        Clears all substitutions requests.

        Returns
        -------
        None

        """
        return _BRepTools.BRepTools_ReShape_Clear(self, *args)

    def CopyVertex(self, *args) -> "TopoDS_Vertex":
        r"""
        Returns modified copy of vertex if original one is not recorded or returns modified original vertex otherwise.

        Parameters
        ----------
        theV: TopoDS_Vertex
        theTol: float,optional
        	default value is -1.0

        Returns
        -------
        TopoDS_Vertex
        Returns modified copy of vertex if original one is not recorded or returns modified original vertex otherwise.

        Parameters
        ----------
        theV: TopoDS_Vertex
        theNewPos: gp_Pnt
        aTol: float

        Returns
        -------
        TopoDS_Vertex

        """
        return _BRepTools.BRepTools_ReShape_CopyVertex(self, *args)

    def History(self, *args) -> "opencascade::handle< BRepTools_History >":
        r"""
        Returns the history of the substituted shapes.

        Returns
        -------
        opencascade::handle<BRepTools_History>

        """
        return _BRepTools.BRepTools_ReShape_History(self, *args)

    def IsNewShape(self, *args) -> "Standard_Boolean":
        r"""
        Checks if shape has been recorded by reshaper as a value.

        Parameters
        ----------
        theShape: TopoDS_Shape

        Returns
        -------
        bool

        """
        return _BRepTools.BRepTools_ReShape_IsNewShape(self, *args)

    def IsRecorded(self, *args) -> "Standard_Boolean":
        r"""
        Tells if a shape is recorded for replace/remove.

        Parameters
        ----------
        shape: TopoDS_Shape

        Returns
        -------
        bool

        """
        return _BRepTools.BRepTools_ReShape_IsRecorded(self, *args)

    def ModeConsiderLocation(self, *args) -> "Standard_Boolean &":
        r"""
        Returns (modifiable) the flag which defines whether location of shape take into account during replacing shapes.

        Returns
        -------
        bool

        """
        return _BRepTools.BRepTools_ReShape_ModeConsiderLocation(self, *args)

    def Remove(self, *args) -> "void":
        r"""
        Sets a request to remove a shape whatever the orientation.

        Parameters
        ----------
        shape: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepTools.BRepTools_ReShape_Remove(self, *args)

    def Replace(self, *args) -> "void":
        r"""
        Sets a request to replace a shape by a new one.

        Parameters
        ----------
        shape: TopoDS_Shape
        newshape: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepTools.BRepTools_ReShape_Replace(self, *args)

    def Status(self, *args) -> "Standard_Integer":
        r"""
        Returns a complete substitution status for a shape 0 : not recorded, <newsh> = original <shape> < 0: to be removed, <newsh> is null > 0: to be replaced, <newsh> is a new item if <last> is false, returns status and new shape recorded in the map directly for the shape, if true and status > 0 then recursively searches for the last status and new shape.

        Parameters
        ----------
        shape: TopoDS_Shape
        newsh: TopoDS_Shape
        last: bool,optional
        	default value is Standard_False

        Returns
        -------
        int

        """
        return _BRepTools.BRepTools_ReShape_Status(self, *args)

    def Value(self, *args) -> "TopoDS_Shape":
        r"""
        Returns the new value for an individual shape if not recorded, returns the original shape itself if to be removed, returns a null shape else, returns the replacing item.

        Parameters
        ----------
        shape: TopoDS_Shape

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepTools.BRepTools_ReShape_Value(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BRepTools_ReShape_DownCast(t)


    __repr__ = _dumps_object

    @methodnotwrapped
    def Merge(self):
    	pass

    __swig_destroy__ = _BRepTools.delete_BRepTools_ReShape

# Register BRepTools_ReShape in _BRepTools:
_BRepTools.BRepTools_ReShape_swigregister(BRepTools_ReShape)

class BRepTools_ShapeSet(OCC.Core.TopTools.TopTools_ShapeSet):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Builds an empty shapeset. parameter <iswithtriangles> is added for xml persistence.

        Parameters
        ----------
        isWithTriangles: bool,optional
        	default value is Standard_True

        Returns
        -------
        None
        Builds an empty shapeset. parameter <iswithtriangles> is added for xml persistence.

        Parameters
        ----------
        B: BRep_Builder
        isWithTriangles: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        _BRepTools.BRepTools_ShapeSet_swiginit(self, _BRepTools.new_BRepTools_ShapeSet(*args))

    def DumpGeometryToString(self) -> "std::string":
        r"""DumpGeometryToString(BRepTools_ShapeSet self) -> std::string"""
        return _BRepTools.BRepTools_ShapeSet_DumpGeometryToString(self)

    def DumpPolygon3DToString(self) -> "std::string":
        r"""DumpPolygon3DToString(BRepTools_ShapeSet self) -> std::string"""
        return _BRepTools.BRepTools_ShapeSet_DumpPolygon3DToString(self)

    def DumpPolygonOnTriangulationToString(self) -> "std::string":
        r"""DumpPolygonOnTriangulationToString(BRepTools_ShapeSet self) -> std::string"""
        return _BRepTools.BRepTools_ShapeSet_DumpPolygonOnTriangulationToString(self)

    def DumpTriangulationToString(self) -> "std::string":
        r"""DumpTriangulationToString(BRepTools_ShapeSet self) -> std::string"""
        return _BRepTools.BRepTools_ShapeSet_DumpTriangulationToString(self)

    def ReadGeometryFromString(self, src: "std::string") -> "void":
        r"""ReadGeometryFromString(BRepTools_ShapeSet self, std::string src)"""
        return _BRepTools.BRepTools_ShapeSet_ReadGeometryFromString(self, src)

    def ReadPolygon3DFromString(self, src: "std::string") -> "void":
        r"""ReadPolygon3DFromString(BRepTools_ShapeSet self, std::string src)"""
        return _BRepTools.BRepTools_ShapeSet_ReadPolygon3DFromString(self, src)

    def ReadPolygonOnTriangulationFromString(self, src: "std::string") -> "void":
        r"""ReadPolygonOnTriangulationFromString(BRepTools_ShapeSet self, std::string src)"""
        return _BRepTools.BRepTools_ShapeSet_ReadPolygonOnTriangulationFromString(self, src)

    def ReadTriangulationFromString(self, src: "std::string") -> "void":
        r"""ReadTriangulationFromString(BRepTools_ShapeSet self, std::string src)"""
        return _BRepTools.BRepTools_ShapeSet_ReadTriangulationFromString(self, src)

    def WriteGeometryToString(self) -> "std::string":
        r"""WriteGeometryToString(BRepTools_ShapeSet self) -> std::string"""
        return _BRepTools.BRepTools_ShapeSet_WriteGeometryToString(self)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepTools.delete_BRepTools_ShapeSet

# Register BRepTools_ShapeSet in _BRepTools:
_BRepTools.BRepTools_ShapeSet_swigregister(BRepTools_ShapeSet)

class BRepTools_Substitution(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _BRepTools.BRepTools_Substitution_swiginit(self, _BRepTools.new_BRepTools_Substitution(*args))

    def Build(self, *args) -> "void":
        r"""
        Build newshape from <s> if its subshapes has modified. //! the methods <iscopied> and <copy> allows you to keep the resul of <build>.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        None

        """
        return _BRepTools.BRepTools_Substitution_Build(self, *args)

    def Clear(self, *args) -> "void":
        r"""
        Reset all the fields.

        Returns
        -------
        None

        """
        return _BRepTools.BRepTools_Substitution_Clear(self, *args)

    def Copy(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Returns the set of shapes substitued to <s> .

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        TopTools_ListOfShape

        """
        return _BRepTools.BRepTools_Substitution_Copy(self, *args)

    def IsCopied(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if <s> has been replaced .

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        bool

        """
        return _BRepTools.BRepTools_Substitution_IsCopied(self, *args)

    def Substitute(self, *args) -> "void":
        r"""
        <oldshape> will be replaced by <newshapes>. //! <newshapes> can be empty , in this case <oldshape> will disparate from its ancestors. //! if an item of <newshapes> is oriented forward. it will be oriented as <oldshape> in its ancestors. else it will be reversed.

        Parameters
        ----------
        OldShape: TopoDS_Shape
        NewShapes: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _BRepTools.BRepTools_Substitution_Substitute(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepTools.delete_BRepTools_Substitution

# Register BRepTools_Substitution in _BRepTools:
_BRepTools.BRepTools_Substitution_swigregister(BRepTools_Substitution)

class BRepTools_WireExplorer(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs an empty explorer (which can be initialized using init).

        Returns
        -------
        None
        Iinitializes an exploration of the wire <w>.

        Parameters
        ----------
        W: TopoDS_Wire

        Returns
        -------
        None
        Initializes an exploration of the wire <w>. f is used to select the edge connected to the previous in the parametric representation of <f>.

        Parameters
        ----------
        W: TopoDS_Wire
        F: TopoDS_Face

        Returns
        -------
        None

        """
        _BRepTools.BRepTools_WireExplorer_swiginit(self, _BRepTools.new_BRepTools_WireExplorer(*args))

    def Clear(self, *args) -> "void":
        r"""
        Clears the content of the explorer.

        Returns
        -------
        None

        """
        return _BRepTools.BRepTools_WireExplorer_Clear(self, *args)

    def Current(self, *args) -> "TopoDS_Edge const":
        r"""
        Returns the current edge.

        Returns
        -------
        TopoDS_Edge

        """
        return _BRepTools.BRepTools_WireExplorer_Current(self, *args)

    def CurrentVertex(self, *args) -> "TopoDS_Vertex const":
        r"""
        Returns the vertex connecting the current edge to the previous one.

        Returns
        -------
        TopoDS_Vertex

        """
        return _BRepTools.BRepTools_WireExplorer_CurrentVertex(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initializes an exploration of the wire <w>.

        Parameters
        ----------
        W: TopoDS_Wire

        Returns
        -------
        None
        Initializes an exploration of the wire <w>. f is used to select the edge connected to the previous in the parametric representation of <f>.

        Parameters
        ----------
        W: TopoDS_Wire
        F: TopoDS_Face

        Returns
        -------
        None
        Initializes an exploration of the wire <w>. f is used to select the edge connected to the previous in the parametric representation of <f>. <umin>, <umax>, <vmin>, <vmax> - the uv bounds of the face <f>.

        Parameters
        ----------
        W: TopoDS_Wire
        F: TopoDS_Face
        UMin: float
        UMax: float
        VMin: float
        VMax: float

        Returns
        -------
        None

        """
        return _BRepTools.BRepTools_WireExplorer_Init(self, *args)

    def More(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if there is a current edge.

        Returns
        -------
        bool

        """
        return _BRepTools.BRepTools_WireExplorer_More(self, *args)

    def Next(self, *args) -> "void":
        r"""
        Proceeds to the next edge.

        Returns
        -------
        None

        """
        return _BRepTools.BRepTools_WireExplorer_Next(self, *args)

    def Orientation(self, *args) -> "TopAbs_Orientation":
        r"""
        Returns an orientation for the current edge.

        Returns
        -------
        TopAbs_Orientation

        """
        return _BRepTools.BRepTools_WireExplorer_Orientation(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepTools.delete_BRepTools_WireExplorer

# Register BRepTools_WireExplorer in _BRepTools:
_BRepTools.BRepTools_WireExplorer_swigregister(BRepTools_WireExplorer)

class BRepTools_GTrsfModification(BRepTools_Modification):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        T: gp_GTrsf

        Returns
        -------
        None

        """
        _BRepTools.BRepTools_GTrsfModification_swiginit(self, _BRepTools.new_BRepTools_GTrsfModification(*args))

    def GTrsf(self, *args) -> "gp_GTrsf":
        r"""
        Gives an access on the gtrsf.

        Returns
        -------
        gp_GTrsf

        """
        return _BRepTools.BRepTools_GTrsfModification_GTrsf(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BRepTools_GTrsfModification_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BRepTools.delete_BRepTools_GTrsfModification

# Register BRepTools_GTrsfModification in _BRepTools:
_BRepTools.BRepTools_GTrsfModification_swigregister(BRepTools_GTrsfModification)

class BRepTools_NurbsConvertModification(BRepTools_Modification):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _BRepTools.BRepTools_NurbsConvertModification_swiginit(self, _BRepTools.new_BRepTools_NurbsConvertModification(*args))

    def GetUpdatedEdges(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        No available documentation.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _BRepTools.BRepTools_NurbsConvertModification_GetUpdatedEdges(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BRepTools_NurbsConvertModification_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BRepTools.delete_BRepTools_NurbsConvertModification

# Register BRepTools_NurbsConvertModification in _BRepTools:
_BRepTools.BRepTools_NurbsConvertModification_swigregister(BRepTools_NurbsConvertModification)

class BRepTools_TrsfModification(BRepTools_Modification):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        T: gp_Trsf

        Returns
        -------
        None

        """
        _BRepTools.BRepTools_TrsfModification_swiginit(self, _BRepTools.new_BRepTools_TrsfModification(*args))

    def Trsf(self, *args) -> "gp_Trsf":
        r"""
        Provides access to the gp_trsf associated with this modification. the transformation can be changed.

        Returns
        -------
        gp_Trsf

        """
        return _BRepTools.BRepTools_TrsfModification_Trsf(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BRepTools_TrsfModification_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BRepTools.delete_BRepTools_TrsfModification

# Register BRepTools_TrsfModification in _BRepTools:
_BRepTools.BRepTools_TrsfModification_swigregister(BRepTools_TrsfModification)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TopoDS import *
from OCC.Core.gp import *
from OCC.Core.TopAbs import *
from OCC.Core.IntCurveSurface import *
from OCC.Core.Bnd import *
from OCC.Core.TopTools import *
from OCC.Core.IntCurvesFace import *
from OCC.Core.BRepAdaptor import *

#the following typedef cannot be wrapped as is
BRepClass3d_BndBoxTree = NewType('BRepClass3d_BndBoxTree', Any)

class brepclass3d:
	@staticmethod
	def OuterShell(S: TopoDS_Solid) -> TopoDS_Shell: ...

class BRepClass3d_Intersector3d:
	def __init__(self) -> None: ...
	def Face(self) -> TopoDS_Face: ...
	def HasAPoint(self) -> bool: ...
	def IsDone(self) -> bool: ...
	def Perform(self, L: gp_Lin, Prm: float, Tol: float, F: TopoDS_Face) -> None: ...
	def Pnt(self) -> gp_Pnt: ...
	def State(self) -> TopAbs_State: ...
	def Transition(self) -> IntCurveSurface_TransitionOnCurve: ...
	def UParameter(self) -> float: ...
	def VParameter(self) -> float: ...
	def WParameter(self) -> float: ...

class BRepClass3d_SClassifier:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: BRepClass3d_SolidExplorer, P: gp_Pnt, Tol: float) -> None: ...
	def Face(self) -> TopoDS_Face: ...
	def IsOnAFace(self) -> bool: ...
	def Perform(self, S: BRepClass3d_SolidExplorer, P: gp_Pnt, Tol: float) -> None: ...
	def PerformInfinitePoint(self, S: BRepClass3d_SolidExplorer, Tol: float) -> None: ...
	def Rejected(self) -> bool: ...
	def State(self) -> TopAbs_State: ...

class BRepClass3d_SolidExplorer:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Shape) -> None: ...
	def Box(self) -> Bnd_Box: ...
	def CurrentFace(self) -> TopoDS_Face: ...
	def CurrentShell(self) -> TopoDS_Shell: ...
	def Destroy(self) -> None: ...
	def DumpSegment(self, P: gp_Pnt, L: gp_Lin, Par: float, S: TopAbs_State) -> None: ...
	@overload
	@staticmethod
	def FindAPointInTheFace(F: TopoDS_Face, P: gp_Pnt) -> Tuple[bool, float]: ...
	@overload
	@staticmethod
	def FindAPointInTheFace(F: TopoDS_Face, P: gp_Pnt) -> Tuple[bool, float, float, float]: ...
	@overload
	@staticmethod
	def FindAPointInTheFace(F: TopoDS_Face, P: gp_Pnt, theVecD1U: gp_Vec, theVecD1V: gp_Vec) -> Tuple[bool, float, float, float]: ...
	@overload
	@staticmethod
	def FindAPointInTheFace(F: TopoDS_Face, P: gp_Pnt) -> Tuple[bool, float, float]: ...
	@overload
	@staticmethod
	def FindAPointInTheFace(F: TopoDS_Face, P: gp_Pnt) -> bool: ...
	@overload
	@staticmethod
	def FindAPointInTheFace(F: TopoDS_Face) -> Tuple[bool, float, float]: ...
	def GetFaceSegmentIndex(self) -> int: ...
	def GetMapEV(self) -> TopTools_IndexedMapOfShape: ...
	def GetShape(self) -> TopoDS_Shape: ...
	def GetTree(self) -> BRepClass3d_BndBoxTree: ...
	def InitFace(self) -> None: ...
	def InitShape(self, S: TopoDS_Shape) -> None: ...
	def InitShell(self) -> None: ...
	def Intersector(self, F: TopoDS_Face) -> IntCurvesFace_Intersector: ...
	def MoreFace(self) -> bool: ...
	def MoreShell(self) -> bool: ...
	def NextFace(self) -> None: ...
	def NextShell(self) -> None: ...
	def OtherSegment(self, P: gp_Pnt, L: gp_Lin) -> Tuple[int, float]: ...
	@overload
	def PointInTheFace(self, F: TopoDS_Face, P: gp_Pnt) -> Tuple[bool, float, float, float, int]: ...
	@overload
	def PointInTheFace(self, F: TopoDS_Face, P: gp_Pnt, surf: BRepAdaptor_HSurface, u1: float, v1: float, u2: float, v2: float) -> Tuple[bool, float, float, float, int]: ...
	@overload
	def PointInTheFace(self, F: TopoDS_Face, P: gp_Pnt, surf: BRepAdaptor_HSurface, u1: float, v1: float, u2: float, v2: float, theVecD1U: gp_Vec, theVecD1V: gp_Vec) -> Tuple[bool, float, float, float, int]: ...
	def Reject(self, P: gp_Pnt) -> bool: ...
	def RejectFace(self, L: gp_Lin) -> bool: ...
	def RejectShell(self, L: gp_Lin) -> bool: ...
	def Segment(self, P: gp_Pnt, L: gp_Lin) -> Tuple[int, float]: ...

class BRepClass3d_SolidPassiveClassifier:
	def __init__(self) -> None: ...
	def Compare(self, F: TopoDS_Face, Or: TopAbs_Orientation) -> None: ...
	def HasIntersection(self) -> bool: ...
	def Intersector(self) -> BRepClass3d_Intersector3d: ...
	def Parameter(self) -> float: ...
	def Reset(self, L: gp_Lin, P: float, Tol: float) -> None: ...
	def State(self) -> TopAbs_State: ...

class BRepClass3d_SolidClassifier(BRepClass3d_SClassifier):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Shape) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Shape, P: gp_Pnt, Tol: float) -> None: ...
	def Destroy(self) -> None: ...
	def Load(self, S: TopoDS_Shape) -> None: ...
	def Perform(self, P: gp_Pnt, Tol: float) -> None: ...
	def PerformInfinitePoint(self, Tol: float) -> None: ...

#classnotwrapped
class BRepClass3d_BndBoxTreeSelectorLine: ...

#classnotwrapped
class BRepClass3d_BndBoxTreeSelectorPoint: ...

# harray1 classes
# harray2 classes
# hsequence classes

brepclass3d_OuterShell = brepclass3d.OuterShell
BRepClass3d_SolidExplorer_FindAPointInTheFace = BRepClass3d_SolidExplorer.FindAPointInTheFace
BRepClass3d_SolidExplorer_FindAPointInTheFace = BRepClass3d_SolidExplorer.FindAPointInTheFace
BRepClass3d_SolidExplorer_FindAPointInTheFace = BRepClass3d_SolidExplorer.FindAPointInTheFace
BRepClass3d_SolidExplorer_FindAPointInTheFace = BRepClass3d_SolidExplorer.FindAPointInTheFace
BRepClass3d_SolidExplorer_FindAPointInTheFace = BRepClass3d_SolidExplorer.FindAPointInTheFace
BRepClass3d_SolidExplorer_FindAPointInTheFace = BRepClass3d_SolidExplorer.FindAPointInTheFace



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Message import *
from OCC.Core.BinMDF import *
from OCC.Core.TDocStd import *
from OCC.Core.BinDrivers import *


class binxcafdrivers:
	@staticmethod
	def AttributeDrivers(MsgDrv: Message_Messenger) -> BinMDF_ADriverTable: ...
	@staticmethod
	def DefineFormat(theApp: TDocStd_Application) -> None: ...
	@staticmethod
	def Factory(theGUID: Standard_GUID) -> Standard_Transient: ...

class BinXCAFDrivers_DocumentRetrievalDriver(BinDrivers_DocumentRetrievalDriver):
	def __init__(self) -> None: ...
	def AttributeDrivers(self, theMsgDriver: Message_Messenger) -> BinMDF_ADriverTable: ...

class BinXCAFDrivers_DocumentStorageDriver(BinDrivers_DocumentStorageDriver):
	def __init__(self) -> None: ...
	def AttributeDrivers(self, theMsgDriver: Message_Messenger) -> BinMDF_ADriverTable: ...

# harray1 classes
# harray2 classes
# hsequence classes

binxcafdrivers_AttributeDrivers = binxcafdrivers.AttributeDrivers
binxcafdrivers_DefineFormat = binxcafdrivers.DefineFormat
binxcafdrivers_Factory = binxcafdrivers.Factory



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _Addons
else:
    import _Addons

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)



def process_exception(error: "Standard_Failure const &", method_name: "std::string", class_name: "std::string") -> "void":
    return _Addons.process_exception(error, method_name, class_name)
Font_FontAspect_UNDEFINED = _Addons.Font_FontAspect_UNDEFINED
Font_FontAspect_Regular = _Addons.Font_FontAspect_Regular
Font_FontAspect_Bold = _Addons.Font_FontAspect_Bold
Font_FontAspect_Italic = _Addons.Font_FontAspect_Italic
Font_FontAspect_BoldItalic = _Addons.Font_FontAspect_BoldItalic
Font_FA_Undefined = _Addons.Font_FA_Undefined
Font_FA_Regular = _Addons.Font_FA_Regular
Font_FA_Bold = _Addons.Font_FA_Bold
Font_FA_Italic = _Addons.Font_FA_Italic
Font_FA_BoldItalic = _Addons.Font_FA_BoldItalic

def text_to_brep(*args) -> "TopoDS_Shape":
    r"""
    * Creates a shape of the given text. 
    :param text_to_render: Text to render
    :type text_to_render: char *
    :param aFontName: Font name
    :type aFontName: char *
    :param aFontAspect:  Fontaspect, FontAspect_UNDEFINED, Font_FontAspect_Regular, Font_FontAspect_Bold, Font_FA_Italic or Font_FA_BoldItalic
    :type aFontAspect: Font_FontAspect
    :param aSize: Size of the font
    :type aSize: float
    :param isCompositeCurve:
    :type isCompositeCurve: bool
    :rtype: TopoDS_Shape

    """
    return _Addons.text_to_brep(*args)

def register_font(*args) -> "void":
    r"""
    * Add a font to the available font list. 
    :param aFontPath: Path to the font.
    :type aFontPath: char *
    :param aFontAspect
    :type Font_FontAspect
    :rtype: void

    """
    return _Addons.register_font(*args)





from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TopAbs import *


class Sweep_NumShape:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Index: int, Type: TopAbs_ShapeEnum, Closed: Optional[bool] = False, BegInf: Optional[bool] = False, EndInf: Optional[bool] = False) -> None: ...
	def BegInfinite(self) -> bool: ...
	def Closed(self) -> bool: ...
	def EndInfinite(self) -> bool: ...
	def Index(self) -> int: ...
	def Init(self, Index: int, Type: TopAbs_ShapeEnum, Closed: Optional[bool] = False, BegInf: Optional[bool] = False, EndInf: Optional[bool] = False) -> None: ...
	def Orientation(self) -> TopAbs_Orientation: ...
	def Type(self) -> TopAbs_ShapeEnum: ...

class Sweep_NumShapeIterator:
	def __init__(self) -> None: ...
	def Init(self, aShape: Sweep_NumShape) -> None: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def Orientation(self) -> TopAbs_Orientation: ...
	def Value(self) -> Sweep_NumShape: ...

class Sweep_NumShapeTool:
	def __init__(self, aShape: Sweep_NumShape) -> None: ...
	def FirstVertex(self) -> Sweep_NumShape: ...
	def HasFirstVertex(self) -> bool: ...
	def HasLastVertex(self) -> bool: ...
	def Index(self, aShape: Sweep_NumShape) -> int: ...
	def LastVertex(self) -> Sweep_NumShape: ...
	def NbShapes(self) -> int: ...
	def Orientation(self, aShape: Sweep_NumShape) -> TopAbs_Orientation: ...
	def Shape(self, anIndex: int) -> Sweep_NumShape: ...
	def Type(self, aShape: Sweep_NumShape) -> TopAbs_ShapeEnum: ...

# harray1 classes
# harray2 classes
# hsequence classes




# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
Hatch module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_hatch.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _Hatch
else:
    import _Hatch

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _Hatch.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _Hatch.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _Hatch.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _Hatch.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _Hatch.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _Hatch.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _Hatch.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _Hatch.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _Hatch.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _Hatch.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _Hatch.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _Hatch.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _Hatch.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _Hatch.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _Hatch.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _Hatch.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _Hatch.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _Hatch:
_Hatch.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _Hatch.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection

from enum import IntEnum
from OCC.Core.Exception import *

Hatch_XLINE = _Hatch.Hatch_XLINE
Hatch_YLINE = _Hatch.Hatch_YLINE
Hatch_ANYLINE = _Hatch.Hatch_ANYLINE


class Hatch_LineForm(IntEnum):
	Hatch_XLINE = 0
	Hatch_YLINE = 1
	Hatch_ANYLINE = 2
Hatch_XLINE = Hatch_LineForm.Hatch_XLINE
Hatch_YLINE = Hatch_LineForm.Hatch_YLINE
Hatch_ANYLINE = Hatch_LineForm.Hatch_ANYLINE

class Hatch_SequenceOfLine(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< Hatch_Line >::iterator":
        return _Hatch.Hatch_SequenceOfLine_begin(self)

    def end(self) -> "NCollection_Sequence< Hatch_Line >::iterator":
        return _Hatch.Hatch_SequenceOfLine_end(self)

    def cbegin(self) -> "NCollection_Sequence< Hatch_Line >::const_iterator":
        return _Hatch.Hatch_SequenceOfLine_cbegin(self)

    def cend(self) -> "NCollection_Sequence< Hatch_Line >::const_iterator":
        return _Hatch.Hatch_SequenceOfLine_cend(self)

    def __init__(self, *args):
        _Hatch.Hatch_SequenceOfLine_swiginit(self, _Hatch.new_Hatch_SequenceOfLine(*args))

    def Size(self) -> "Standard_Integer":
        return _Hatch.Hatch_SequenceOfLine_Size(self)

    def Length(self) -> "Standard_Integer":
        return _Hatch.Hatch_SequenceOfLine_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _Hatch.Hatch_SequenceOfLine_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _Hatch.Hatch_SequenceOfLine_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _Hatch.Hatch_SequenceOfLine_IsEmpty(self)

    def Reverse(self) -> "void":
        return _Hatch.Hatch_SequenceOfLine_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _Hatch.Hatch_SequenceOfLine_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _Hatch.Hatch_SequenceOfLine_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _Hatch.Hatch_SequenceOfLine_Clear(self, theAllocator)

    def Assign(self, theOther: "Hatch_SequenceOfLine") -> "NCollection_Sequence< Hatch_Line > &":
        return _Hatch.Hatch_SequenceOfLine_Assign(self, theOther)

    def Set(self, theOther: "Hatch_SequenceOfLine") -> "NCollection_Sequence< Hatch_Line > &":
        return _Hatch.Hatch_SequenceOfLine_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _Hatch.Hatch_SequenceOfLine_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _Hatch.Hatch_SequenceOfLine_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _Hatch.Hatch_SequenceOfLine_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _Hatch.Hatch_SequenceOfLine_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _Hatch.Hatch_SequenceOfLine_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "Hatch_SequenceOfLine") -> "void":
        return _Hatch.Hatch_SequenceOfLine_Split(self, theIndex, theSeq)

    def First(self) -> "Hatch_Line const &":
        return _Hatch.Hatch_SequenceOfLine_First(self)

    def ChangeFirst(self) -> "Hatch_Line &":
        return _Hatch.Hatch_SequenceOfLine_ChangeFirst(self)

    def Last(self) -> "Hatch_Line const &":
        return _Hatch.Hatch_SequenceOfLine_Last(self)

    def ChangeLast(self) -> "Hatch_Line &":
        return _Hatch.Hatch_SequenceOfLine_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "Hatch_Line const &":
        return _Hatch.Hatch_SequenceOfLine_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "Hatch_Line &":
        return _Hatch.Hatch_SequenceOfLine_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "Hatch_Line &":
        return _Hatch.Hatch_SequenceOfLine___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "Hatch_Line") -> "void":
        return _Hatch.Hatch_SequenceOfLine_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _Hatch.delete_Hatch_SequenceOfLine

    def __len__(self):
        return self.Size()


# Register Hatch_SequenceOfLine in _Hatch:
_Hatch.Hatch_SequenceOfLine_swigregister(Hatch_SequenceOfLine)

def Hatch_SequenceOfLine_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _Hatch.Hatch_SequenceOfLine_delNode(theNode, theAl)

class Hatch_SequenceOfParameter(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< Hatch_Parameter >::iterator":
        return _Hatch.Hatch_SequenceOfParameter_begin(self)

    def end(self) -> "NCollection_Sequence< Hatch_Parameter >::iterator":
        return _Hatch.Hatch_SequenceOfParameter_end(self)

    def cbegin(self) -> "NCollection_Sequence< Hatch_Parameter >::const_iterator":
        return _Hatch.Hatch_SequenceOfParameter_cbegin(self)

    def cend(self) -> "NCollection_Sequence< Hatch_Parameter >::const_iterator":
        return _Hatch.Hatch_SequenceOfParameter_cend(self)

    def __init__(self, *args):
        _Hatch.Hatch_SequenceOfParameter_swiginit(self, _Hatch.new_Hatch_SequenceOfParameter(*args))

    def Size(self) -> "Standard_Integer":
        return _Hatch.Hatch_SequenceOfParameter_Size(self)

    def Length(self) -> "Standard_Integer":
        return _Hatch.Hatch_SequenceOfParameter_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _Hatch.Hatch_SequenceOfParameter_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _Hatch.Hatch_SequenceOfParameter_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _Hatch.Hatch_SequenceOfParameter_IsEmpty(self)

    def Reverse(self) -> "void":
        return _Hatch.Hatch_SequenceOfParameter_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _Hatch.Hatch_SequenceOfParameter_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _Hatch.Hatch_SequenceOfParameter_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _Hatch.Hatch_SequenceOfParameter_Clear(self, theAllocator)

    def Assign(self, theOther: "Hatch_SequenceOfParameter") -> "NCollection_Sequence< Hatch_Parameter > &":
        return _Hatch.Hatch_SequenceOfParameter_Assign(self, theOther)

    def Set(self, theOther: "Hatch_SequenceOfParameter") -> "NCollection_Sequence< Hatch_Parameter > &":
        return _Hatch.Hatch_SequenceOfParameter_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _Hatch.Hatch_SequenceOfParameter_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _Hatch.Hatch_SequenceOfParameter_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _Hatch.Hatch_SequenceOfParameter_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _Hatch.Hatch_SequenceOfParameter_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _Hatch.Hatch_SequenceOfParameter_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "Hatch_SequenceOfParameter") -> "void":
        return _Hatch.Hatch_SequenceOfParameter_Split(self, theIndex, theSeq)

    def First(self) -> "Hatch_Parameter const &":
        return _Hatch.Hatch_SequenceOfParameter_First(self)

    def ChangeFirst(self) -> "Hatch_Parameter &":
        return _Hatch.Hatch_SequenceOfParameter_ChangeFirst(self)

    def Last(self) -> "Hatch_Parameter const &":
        return _Hatch.Hatch_SequenceOfParameter_Last(self)

    def ChangeLast(self) -> "Hatch_Parameter &":
        return _Hatch.Hatch_SequenceOfParameter_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "Hatch_Parameter const &":
        return _Hatch.Hatch_SequenceOfParameter_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "Hatch_Parameter &":
        return _Hatch.Hatch_SequenceOfParameter_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "Hatch_Parameter &":
        return _Hatch.Hatch_SequenceOfParameter___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "Hatch_Parameter") -> "void":
        return _Hatch.Hatch_SequenceOfParameter_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _Hatch.delete_Hatch_SequenceOfParameter

    def __len__(self):
        return self.Size()


# Register Hatch_SequenceOfParameter in _Hatch:
_Hatch.Hatch_SequenceOfParameter_swigregister(Hatch_SequenceOfParameter)

def Hatch_SequenceOfParameter_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _Hatch.Hatch_SequenceOfParameter_delNode(theNode, theAl)

class Hatch_Hatcher(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a empty hatcher. <tol> is the tolerance for intersections.

        Parameters
        ----------
        Tol: float
        Oriented: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        _Hatch.Hatch_Hatcher_swiginit(self, _Hatch.new_Hatch_Hatcher(*args))

    def AddLine(self, *args) -> "void":
        r"""
        Add a line <l> to be trimmed. <t> the type is only kept from information. it is not used in the computation.

        Parameters
        ----------
        L: gp_Lin2d
        T: Hatch_LineForm,optional
        	default value is Hatch_ANYLINE

        Returns
        -------
        None
        Add an infinite line on direction <d> at distance <dist> from the origin to be trimmed. <dist> may be negative. //! if o is the origin of the 2d plane, and v the vector perpendicular to d (in the direct direction). //! a point p is on the line if : op dot v = dist the parameter of p on the line is op dot d.

        Parameters
        ----------
        D: gp_Dir2d
        Dist: float

        Returns
        -------
        None

        """
        return _Hatch.Hatch_Hatcher_AddLine(self, *args)

    def AddXLine(self, *args) -> "void":
        r"""
        Add an infinite line parallel to the y-axis at abciss <x>.

        Parameters
        ----------
        X: float

        Returns
        -------
        None

        """
        return _Hatch.Hatch_Hatcher_AddXLine(self, *args)

    def AddYLine(self, *args) -> "void":
        r"""
        Add an infinite line parallel to the x-axis at ordinate <y>.

        Parameters
        ----------
        Y: float

        Returns
        -------
        None

        """
        return _Hatch.Hatch_Hatcher_AddYLine(self, *args)

    def Coordinate(self, *args) -> "Standard_Real":
        r"""
        Returns the x or y coordinate of the line of index <i> if it is a x or a y line.

        Parameters
        ----------
        I: int

        Returns
        -------
        float

        """
        return _Hatch.Hatch_Hatcher_Coordinate(self, *args)

    def End(self, *args) -> "Standard_Real":
        r"""
        Returns the last parameter of interval <j> on line <i>.

        Parameters
        ----------
        I: int
        J: int

        Returns
        -------
        float

        """
        return _Hatch.Hatch_Hatcher_End(self, *args)

    def EndIndex(self, *args) -> "void":
        r"""
        Returns the last index and par2 of interval <j> on line <i>.

        Parameters
        ----------
        I: int
        J: int

        Returns
        -------
        Index: int
        Par2: float

        """
        return _Hatch.Hatch_Hatcher_EndIndex(self, *args)

    def IsXLine(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the line of index <i> has a constant x value.

        Parameters
        ----------
        I: int

        Returns
        -------
        bool

        """
        return _Hatch.Hatch_Hatcher_IsXLine(self, *args)

    def IsYLine(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the line of index <i> has a constant y value.

        Parameters
        ----------
        I: int

        Returns
        -------
        bool

        """
        return _Hatch.Hatch_Hatcher_IsYLine(self, *args)

    def Line(self, *args) -> "gp_Lin2d const":
        r"""
        Returns the line of index <i>.

        Parameters
        ----------
        I: int

        Returns
        -------
        gp_Lin2d

        """
        return _Hatch.Hatch_Hatcher_Line(self, *args)

    def LineForm(self, *args) -> "Hatch_LineForm":
        r"""
        Returns the type of the line of index <i>.

        Parameters
        ----------
        I: int

        Returns
        -------
        Hatch_LineForm

        """
        return _Hatch.Hatch_Hatcher_LineForm(self, *args)

    def NbIntervals(self, *args) -> "Standard_Integer":
        r"""
        Returns the total number of intervals on all the lines.

        Returns
        -------
        int
        Returns the number of intervals on line of index <i>.

        Parameters
        ----------
        I: int

        Returns
        -------
        int

        """
        return _Hatch.Hatch_Hatcher_NbIntervals(self, *args)

    def NbLines(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of lines.

        Returns
        -------
        int

        """
        return _Hatch.Hatch_Hatcher_NbLines(self, *args)

    def Start(self, *args) -> "Standard_Real":
        r"""
        Returns the first parameter of interval <j> on line <i>.

        Parameters
        ----------
        I: int
        J: int

        Returns
        -------
        float

        """
        return _Hatch.Hatch_Hatcher_Start(self, *args)

    def StartIndex(self, *args) -> "void":
        r"""
        Returns the first index and par2 of interval <j> on line <i>.

        Parameters
        ----------
        I: int
        J: int

        Returns
        -------
        Index: int
        Par2: float

        """
        return _Hatch.Hatch_Hatcher_StartIndex(self, *args)

    def Tolerance(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Parameters
        ----------
        Tol: float

        Returns
        -------
        None
        No available documentation.

        Returns
        -------
        float

        """
        return _Hatch.Hatch_Hatcher_Tolerance(self, *args)

    def Trim(self, *args) -> "void":
        r"""
        Trims the lines at intersections with <l>.

        Parameters
        ----------
        L: gp_Lin2d
        Index: int,optional
        	default value is 0

        Returns
        -------
        None
        Trims the lines at intersections with <l> in the parameter range <start>, <end>.

        Parameters
        ----------
        L: gp_Lin2d
        Start: float
        End: float
        Index: int,optional
        	default value is 0

        Returns
        -------
        None
        Trims the line at intersection with the oriented segment p1,p2.

        Parameters
        ----------
        P1: gp_Pnt2d
        P2: gp_Pnt2d
        Index: int,optional
        	default value is 0

        Returns
        -------
        None

        """
        return _Hatch.Hatch_Hatcher_Trim(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Hatch.delete_Hatch_Hatcher

# Register Hatch_Hatcher in _Hatch:
_Hatch.Hatch_Hatcher_swigregister(Hatch_Hatcher)

class Hatch_Line(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        L: gp_Lin2d
        T: Hatch_LineForm

        Returns
        -------
        None

        """
        _Hatch.Hatch_Line_swiginit(self, _Hatch.new_Hatch_Line(*args))

    def AddIntersection(self, *args) -> "void":
        r"""
        Insert a new intersection in the sorted list.

        Parameters
        ----------
        Par1: float
        Start: bool
        Index: int
        Par2: float
        theToler: float

        Returns
        -------
        None

        """
        return _Hatch.Hatch_Line_AddIntersection(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Hatch.delete_Hatch_Line

# Register Hatch_Line in _Hatch:
_Hatch.Hatch_Line_swigregister(Hatch_Line)

class Hatch_Parameter(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        Par1: float
        Start: bool
        Index: int,optional
        	default value is 0
        Par2: float,optional
        	default value is 0

        Returns
        -------
        None

        """
        _Hatch.Hatch_Parameter_swiginit(self, _Hatch.new_Hatch_Parameter(*args))

    __repr__ = _dumps_object

    __swig_destroy__ = _Hatch.delete_Hatch_Parameter

# Register Hatch_Parameter in _Hatch:
_Hatch.Hatch_Parameter_swigregister(Hatch_Parameter)








# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
Geom2dEvaluator module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_geom2devaluator.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _Geom2dEvaluator
else:
    import _Geom2dEvaluator

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _Geom2dEvaluator.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _Geom2dEvaluator.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _Geom2dEvaluator.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _Geom2dEvaluator.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _Geom2dEvaluator.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _Geom2dEvaluator.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _Geom2dEvaluator.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _Geom2dEvaluator.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _Geom2dEvaluator.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _Geom2dEvaluator.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _Geom2dEvaluator.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _Geom2dEvaluator.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _Geom2dEvaluator.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _Geom2dEvaluator.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _Geom2dEvaluator.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _Geom2dEvaluator.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _Geom2dEvaluator.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _Geom2dEvaluator:
_Geom2dEvaluator.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _Geom2dEvaluator.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.Geom2d
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.Geom2dAdaptor
import OCC.Core.Adaptor2d

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_Geom2dEvaluator_Curve_Create() -> "opencascade::handle< Geom2dEvaluator_Curve >":
    return _Geom2dEvaluator.Handle_Geom2dEvaluator_Curve_Create()

def Handle_Geom2dEvaluator_Curve_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< Geom2dEvaluator_Curve >":
    return _Geom2dEvaluator.Handle_Geom2dEvaluator_Curve_DownCast(t)

def Handle_Geom2dEvaluator_Curve_IsNull(t: "opencascade::handle< Geom2dEvaluator_Curve > const &") -> "bool":
    return _Geom2dEvaluator.Handle_Geom2dEvaluator_Curve_IsNull(t)

def Handle_Geom2dEvaluator_OffsetCurve_Create() -> "opencascade::handle< Geom2dEvaluator_OffsetCurve >":
    return _Geom2dEvaluator.Handle_Geom2dEvaluator_OffsetCurve_Create()

def Handle_Geom2dEvaluator_OffsetCurve_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< Geom2dEvaluator_OffsetCurve >":
    return _Geom2dEvaluator.Handle_Geom2dEvaluator_OffsetCurve_DownCast(t)

def Handle_Geom2dEvaluator_OffsetCurve_IsNull(t: "opencascade::handle< Geom2dEvaluator_OffsetCurve > const &") -> "bool":
    return _Geom2dEvaluator.Handle_Geom2dEvaluator_OffsetCurve_IsNull(t)
class geom2devaluator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def CalculateD0(*args) -> "void":
        r"""
        Recalculate d1 values of base curve into d0 value of offset curve.

        Parameters
        ----------
        theValue: gp_Pnt2d
        theD1: gp_Vec2d
        theOffset: float

        Returns
        -------
        None

        """
        return _Geom2dEvaluator.geom2devaluator_CalculateD0(*args)

    @staticmethod
    def CalculateD1(*args) -> "void":
        r"""
        Recalculate d2 values of base curve into d1 values of offset curve.

        Parameters
        ----------
        theValue: gp_Pnt2d
        theD1: gp_Vec2d
        theD2: gp_Vec2d
        theOffset: float

        Returns
        -------
        None

        """
        return _Geom2dEvaluator.geom2devaluator_CalculateD1(*args)

    @staticmethod
    def CalculateD2(*args) -> "void":
        r"""
        Recalculate d3 values of base curve into d2 values of offset curve.

        Parameters
        ----------
        theValue: gp_Pnt2d
        theD1: gp_Vec2d
        theD2: gp_Vec2d
        theD3: gp_Vec2d
        theIsDirChange: bool
        theOffset: float

        Returns
        -------
        None

        """
        return _Geom2dEvaluator.geom2devaluator_CalculateD2(*args)

    @staticmethod
    def CalculateD3(*args) -> "void":
        r"""
        Recalculate d3 values of base curve into d3 values of offset curve.

        Parameters
        ----------
        theValue: gp_Pnt2d
        theD1: gp_Vec2d
        theD2: gp_Vec2d
        theD3: gp_Vec2d
        theD4: gp_Vec2d
        theIsDirChange: bool
        theOffset: float

        Returns
        -------
        None

        """
        return _Geom2dEvaluator.geom2devaluator_CalculateD3(*args)

    __repr__ = _dumps_object

    @methodnotwrapped
    def A(self):
    	pass

    @methodnotwrapped
    def d(self):
    	pass

    @methodnotwrapped
    def j(self):
    	pass

    @methodnotwrapped
    def u(self):
    	pass

    @methodnotwrapped
    def s(self):
    	pass

    @methodnotwrapped
    def t(self):
    	pass

    @methodnotwrapped
    def D(self):
    	pass

    @methodnotwrapped
    def e(self):
    	pass

    @methodnotwrapped
    def r(self):
    	pass

    @methodnotwrapped
    def i(self):
    	pass

    @methodnotwrapped
    def v(self):
    	pass

    @methodnotwrapped
    def a(self):
    	pass

    @methodnotwrapped
    def t(self):
    	pass

    @methodnotwrapped
    def i(self):
    	pass

    @methodnotwrapped
    def v(self):
    	pass

    @methodnotwrapped
    def e(self):
    	pass


    def __init__(self):
        _Geom2dEvaluator.geom2devaluator_swiginit(self, _Geom2dEvaluator.new_geom2devaluator())
    __swig_destroy__ = _Geom2dEvaluator.delete_geom2devaluator

# Register geom2devaluator in _Geom2dEvaluator:
_Geom2dEvaluator.geom2devaluator_swigregister(geom2devaluator)

def geom2devaluator_CalculateD0(*args) -> "void":
    r"""
    Recalculate d1 values of base curve into d0 value of offset curve.

    Parameters
    ----------
    theValue: gp_Pnt2d
    theD1: gp_Vec2d
    theOffset: float

    Returns
    -------
    None

    """
    return _Geom2dEvaluator.geom2devaluator_CalculateD0(*args)

def geom2devaluator_CalculateD1(*args) -> "void":
    r"""
    Recalculate d2 values of base curve into d1 values of offset curve.

    Parameters
    ----------
    theValue: gp_Pnt2d
    theD1: gp_Vec2d
    theD2: gp_Vec2d
    theOffset: float

    Returns
    -------
    None

    """
    return _Geom2dEvaluator.geom2devaluator_CalculateD1(*args)

def geom2devaluator_CalculateD2(*args) -> "void":
    r"""
    Recalculate d3 values of base curve into d2 values of offset curve.

    Parameters
    ----------
    theValue: gp_Pnt2d
    theD1: gp_Vec2d
    theD2: gp_Vec2d
    theD3: gp_Vec2d
    theIsDirChange: bool
    theOffset: float

    Returns
    -------
    None

    """
    return _Geom2dEvaluator.geom2devaluator_CalculateD2(*args)

def geom2devaluator_CalculateD3(*args) -> "void":
    r"""
    Recalculate d3 values of base curve into d3 values of offset curve.

    Parameters
    ----------
    theValue: gp_Pnt2d
    theD1: gp_Vec2d
    theD2: gp_Vec2d
    theD3: gp_Vec2d
    theD4: gp_Vec2d
    theIsDirChange: bool
    theOffset: float

    Returns
    -------
    None

    """
    return _Geom2dEvaluator.geom2devaluator_CalculateD3(*args)

class Geom2dEvaluator_Curve(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def D0(self, *args) -> "void":
        r"""
        Value of 2d curve.

        Parameters
        ----------
        theU: float
        theValue: gp_Pnt2d

        Returns
        -------
        None

        """
        return _Geom2dEvaluator.Geom2dEvaluator_Curve_D0(self, *args)

    def D1(self, *args) -> "void":
        r"""
        Value and first derivatives of curve.

        Parameters
        ----------
        theU: float
        theValue: gp_Pnt2d
        theD1: gp_Vec2d

        Returns
        -------
        None

        """
        return _Geom2dEvaluator.Geom2dEvaluator_Curve_D1(self, *args)

    def D2(self, *args) -> "void":
        r"""
        Value, first and second derivatives of curve.

        Parameters
        ----------
        theU: float
        theValue: gp_Pnt2d
        theD1: gp_Vec2d
        theD2: gp_Vec2d

        Returns
        -------
        None

        """
        return _Geom2dEvaluator.Geom2dEvaluator_Curve_D2(self, *args)

    def D3(self, *args) -> "void":
        r"""
        Value, first, second and third derivatives of curve.

        Parameters
        ----------
        theU: float
        theValue: gp_Pnt2d
        theD1: gp_Vec2d
        theD2: gp_Vec2d
        theD3: gp_Vec2d

        Returns
        -------
        None

        """
        return _Geom2dEvaluator.Geom2dEvaluator_Curve_D3(self, *args)

    def DN(self, *args) -> "gp_Vec2d":
        r"""
        Calculates n-th derivatives of curve, where n = thederu. raises if n < 1.

        Parameters
        ----------
        theU: float
        theDerU: int

        Returns
        -------
        gp_Vec2d

        """
        return _Geom2dEvaluator.Geom2dEvaluator_Curve_DN(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_Geom2dEvaluator_Curve_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _Geom2dEvaluator.delete_Geom2dEvaluator_Curve

# Register Geom2dEvaluator_Curve in _Geom2dEvaluator:
_Geom2dEvaluator.Geom2dEvaluator_Curve_swigregister(Geom2dEvaluator_Curve)

class Geom2dEvaluator_OffsetCurve(Geom2dEvaluator_Curve):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Initialize evaluator by curve.

        Parameters
        ----------
        theBase: Geom2d_Curve
        theOffset: float

        Returns
        -------
        None
        Initialize evaluator by curve adaptor.

        Parameters
        ----------
        theBase: Geom2dAdaptor_HCurve
        theOffset: float

        Returns
        -------
        None

        """
        _Geom2dEvaluator.Geom2dEvaluator_OffsetCurve_swiginit(self, _Geom2dEvaluator.new_Geom2dEvaluator_OffsetCurve(*args))

    def SetOffsetValue(self, *args) -> "void":
        r"""
        Change the offset value.

        Parameters
        ----------
        theOffset: float

        Returns
        -------
        None

        """
        return _Geom2dEvaluator.Geom2dEvaluator_OffsetCurve_SetOffsetValue(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_Geom2dEvaluator_OffsetCurve_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _Geom2dEvaluator.delete_Geom2dEvaluator_OffsetCurve

# Register Geom2dEvaluator_OffsetCurve in _Geom2dEvaluator:
_Geom2dEvaluator.Geom2dEvaluator_OffsetCurve_swigregister(Geom2dEvaluator_OffsetCurve)





